Description Details Author(s) References
This package implements the Rectified Factor Networks algorithm as described by Clevert et al., 2014, which is an unsupervised latent variable model.
| Package: | RFN |
| Type: | Package |
| Version: | 0.1 |
| Date: | 2016-02-19 |
| License: | GPL (>= 2) |
The core of this package is the function train_rfn, which trains a Rectified Factor Network
as described by Clevert et al., 2014. Alongside, there exist three basic functions for plotting data,
particularly MNIST pictures, implemented in showSinglePicture, showSingleColorPicture
and showPictures.
Thomas Unterthiner, Thomas Adler
Maintainer: Thomas Unterthiner <unterthiner@bioinf.jku.at>
Clevert DA, Unterthiner T, Mayr A, Ramsauer H, Hochreiter S, "Rectified Factor Networks", http://arxiv.org/abs/1502.06464
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.